==> cds-adapter-odata-v4-2.10.6-sources.jar: com/sap/cds/adapter/odata/v4/serializer/json/options/NavigationProperty2JsonOptions.java <==
/**************************************************************************
 * (C) 2019-2024 SAP SE or an SAP affiliate company. All rights reserved. *
 **************************************************************************/
package com.sap.cds.adapter.odata.v4.serializer.json.options;

import org.apache.olingo.commons.api.data.ContextURL;
import org.apache.olingo.commons.api.format.ContentType;
import org.apache.olingo.server.api.uri.queryoption.CountOption;
import org.apache.olingo.server.api.uri.queryoption.ExpandOption;
import org.apache.olingo.server.api.uri.queryoption.LevelsExpandOption;
import org.apache.olingo.server.api.uri.queryoption.SelectOption;

import com.sap.cds.adapter.odata.v4.CdsRequestGlobals;

/**
 * Options for the navigation property serializers.
 */
public class NavigationProperty2JsonOptions extends CdsODataOptions {

	private CountOption count;
	private ExpandOption expand;
	private SelectOption select;
	private LevelsExpandOption levels;
	private boolean writeOnlyReferences;
	private boolean isFullRepresentation = false;
	private boolean autoExpand;
	private boolean isCountPath = false;

	/** Gets the {@link ContextURL}. */
	public ContextURL getContextURL() {
		return contextURL;
	}

	/** Gets the $count system query option. */
	public CountOption getCount() {
		return count;
	}

	public boolean isCountPath() {
		return isCountPath;
	}

	/** Gets the $expand system query option. */
	public ExpandOption getExpand() {
		return expand;
	}

	/** Gets the $select system query option. */
	public SelectOption getSelect() {
		return select;
	}

	public LevelsExpandOption getLevels() {
		return levels;
	}
	
	/** only writes the references of the entities */
	public boolean getWriteOnlyReferences() {
		return writeOnlyReferences;
	}

	/** Inline entries will not have @delta if representation is full **/ 
	public boolean isFullRepresentation() {
		return isFullRepresentation;
	}

	public boolean isAutoExpand() {
		return autoExpand;
	}

	private NavigationProperty2JsonOptions(ContentType contentType, String odataVersion, CdsRequestGlobals globals) {
		super(contentType, odataVersion, globals);
	}

	/** Initializes the options builder. */
	public static Builder with(ContentType contentType, String odataVersion, CdsRequestGlobals globals) {
		return new Builder(contentType, odataVersion, globals);
	}

	/** Builder of OData serializer options. */
	public static final class Builder {

		private final NavigationProperty2JsonOptions options;

		private Builder(ContentType contentType, String odataVersion, CdsRequestGlobals globals) {
			options = new NavigationProperty2JsonOptions(contentType, odataVersion, globals);
		}

		/** Sets the {@link ContextURL}. */
		public Builder contextURL(ContextURL contextURL) {
			options.contextURL = contextURL;
			return this;
		}

		/** Sets the $count system query option. */
		public Builder count(CountOption count) {
			options.count = count;
			return this;
		}

		public Builder countPath(boolean isCountPath) {
			options.isCountPath = isCountPath;
			return this;
		}

		/** Sets the $expand system query option. */
		public Builder expand(ExpandOption expand) {
			options.expand = expand;
			return this;
		}

		/** Sets the $select system query option. */
		public Builder select(SelectOption select) {
			options.select = select;
			return this;
		}

		/** Sets the $select system query option. */
		public Builder levels(LevelsExpandOption levels) {
			options.levels = levels;
			return this;
		}
		
		/** Sets to serialize only references */
		public Builder writeOnlyReferences(final boolean ref) {
			options.writeOnlyReferences = ref;
			return this;
		}

		/** sets isFullRepresentation to represent inline entries**/
		public Builder isFullRepresentation(boolean isFullRepresentation) {
			options.isFullRepresentation = isFullRepresentation;
			return this;
		}

		public Builder autoExpand(boolean autoExpand) {
			options.autoExpand = autoExpand;
			return this;
		}

		/** Builds the OData serializer options. */
		public NavigationProperty2JsonOptions build() {
			return options;
		}
	}
}

==> cds-adapter-odata-v4-3.9.1-sources.jar: com/sap/cds/adapter/odata/v4/serializer/json/options/NavigationProperty2JsonOptions.java <==
/**************************************************************************
 * (C) 2019-2024 SAP SE or an SAP affiliate company. All rights reserved. *
 **************************************************************************/
package com.sap.cds.adapter.odata.v4.serializer.json.options;

import java.util.Map;

import org.apache.olingo.commons.api.data.ContextURL;
import org.apache.olingo.commons.api.format.ContentType;
import org.apache.olingo.server.api.uri.queryoption.CountOption;
import org.apache.olingo.server.api.uri.queryoption.ExpandOption;
import org.apache.olingo.server.api.uri.queryoption.LevelsExpandOption;
import org.apache.olingo.server.api.uri.queryoption.SelectOption;

import com.sap.cds.adapter.odata.v4.CdsRequestGlobals;

/**
 * Options for the navigation property serializers.
 */
public class NavigationProperty2JsonOptions extends CdsODataOptions {

	private CountOption count;
	private ExpandOption expand;
	private SelectOption select;
	private LevelsExpandOption levels;
	private boolean writeOnlyReferences;
	private boolean isFullRepresentation = false;
	private boolean autoExpand;
	private boolean isCountPath = false;

	/** Gets the {@link ContextURL}. */
	public ContextURL getContextURL() {
		return contextURL;
	}

	/** Gets the $count system query option. */
	public CountOption getCount() {
		return count;
	}

	public boolean isCountPath() {
		return isCountPath;
	}

	/** Gets the $expand system query option. */
	public ExpandOption getExpand() {
		return expand;
	}

	/** Gets the $select system query option. */
	public SelectOption getSelect() {
		return select;
	}

	public LevelsExpandOption getLevels() {
		return levels;
	}
	
	/** only writes the references of the entities */
	public boolean getWriteOnlyReferences() {
		return writeOnlyReferences;
	}

	/** Inline entries will not have @delta if representation is full **/ 
	public boolean isFullRepresentation() {
		return isFullRepresentation;
	}

	public boolean isAutoExpand() {
		return autoExpand;
	}

	private NavigationProperty2JsonOptions(ContentType contentType, String odataVersion, CdsRequestGlobals globals,
			Map<String, String> preferenceApplied) {
		super(contentType, odataVersion, globals, preferenceApplied);
	}

	/** Initializes the options builder. */
	public static Builder with(ContentType contentType, String odataVersion, CdsRequestGlobals globals) {
		return with(contentType, odataVersion, globals, null);
	}

	public static Builder with(ContentType contentType, String odataVersion, CdsRequestGlobals globals,
			Map<String, String> preferenceApplied) {
		return new Builder(contentType, odataVersion, globals, preferenceApplied);
	}

	/** Builder of OData serializer options. */
	public static final class Builder {

		private final NavigationProperty2JsonOptions options;

		private Builder(ContentType contentType, String odataVersion, CdsRequestGlobals globals,
		Map<String, String> preferenceApplied) {
			options = new NavigationProperty2JsonOptions(contentType, odataVersion, globals, preferenceApplied);
		}

		/** Sets the {@link ContextURL}. */
		public Builder contextURL(ContextURL contextURL) {
			options.contextURL = contextURL;
			return this;
		}

		/** Sets the $count system query option. */
		public Builder count(CountOption count) {
			options.count = count;
			return this;
		}

		public Builder countPath(boolean isCountPath) {
			options.isCountPath = isCountPath;
			return this;
		}

		/** Sets the $expand system query option. */
		public Builder expand(ExpandOption expand) {
			options.expand = expand;
			return this;
		}

		/** Sets the $select system query option. */
		public Builder select(SelectOption select) {
			options.select = select;
			return this;
		}

		/** Sets the $select system query option. */
		public Builder levels(LevelsExpandOption levels) {
			options.levels = levels;
			return this;
		}
		
		/** Sets to serialize only references */
		public Builder writeOnlyReferences(final boolean ref) {
			options.writeOnlyReferences = ref;
			return this;
		}

		/** sets isFullRepresentation to represent inline entries**/
		public Builder isFullRepresentation(boolean isFullRepresentation) {
			options.isFullRepresentation = isFullRepresentation;
			return this;
		}

		public Builder autoExpand(boolean autoExpand) {
			options.autoExpand = autoExpand;
			return this;
		}

		/** Builds the OData serializer options. */
		public NavigationProperty2JsonOptions build() {
			return options;
		}
	}
}
